==> wcax-shared-angular-1.0.0.tgz: package/modal/modal.component.ts <==
import { Component, Injectable, Input, OnInit, ElementRef, AfterViewInit } from "@angular/core";

// Services
import { ModalService } from "./modal.service";
import { ClipService } from "../../core/clip.service";
import { BoxtopService } from "../../j4u/boxtop/boxtop.service";

// Data model
import { RewardModel } from "../data.model";

// jQuery
declare var $: any;

function _window(): any {
    return window;
}
@Component({
    selector: "modal",
    templateUrl: "./modal.component.html"
})
@Injectable()
export class ModalComponent implements OnInit, AfterViewInit {
    public modal: any = {
        title: "",
        titleBorder: false,
        id: "",
        modalClass: "",
        isRewardsSelected: false,
        isRewardsRedemption: false,
        isBoxtop: false,
        isServiceDetails: false,
        type: '',
        actionButton: '',
        reward: {},
        rewardId: '',
        displayRedemptionButton: false,
        titleId: ''
    };
    public rewardsSelected: RewardModel[] = [];

    public constructor(
        public elementRef: ElementRef,
        private _modalService: ModalService,
        private couponClipFn: ClipService,
        private objBoxTop: BoxtopService
    ) {}

    public ngOnInit() {
        if(this.elementRef.nativeElement.getAttribute("data-modal-type")) this.modal.type = this.elementRef.nativeElement.getAttribute("data-modal-type");
        if(this.elementRef.nativeElement.getAttribute("data-modal-parent")) this.modal.parent = this.elementRef.nativeElement.getAttribute("data-modal-parent");
        if(this.elementRef.nativeElement.getAttribute("data-modal-reward-id")) this.modal.rewardId = this.elementRef.nativeElement.getAttribute("data-modal-reward-id");
        if(this.elementRef.nativeElement.getAttribute("data-modal-actionButton")) this.modal.actionButton = this.elementRef.nativeElement.getAttribute("data-modal-actionButton");
        if(this.elementRef.nativeElement.getAttribute("data-modal-displayRedemptionButton")) this.modal.displayRedemptionButton = this.elementRef.nativeElement.getAttribute("data-modal-displayRedemptionButton");

        if (this.modal.type == "rewards-selected") {
            this.modal.title = "My Selected Rewards:";
            this.modal.titleId="rewards-selected-modal-title";
            this.modal.titleBorder = true;
            this.modal.id = "rewards-selected-modal";
            this.modal.describedId = this.modal.titleId;
            this.modal.isRewardsSelected = true;
        } else if (this.modal.type == "boxtop") {
            this.modal.title = "Get started today - enroll in Box Tops for Education";
            this.modal.titleBorder = false;
            this.modal.titleId = 'boxtopModalTitle';
            switch (this.modal.parent) {
                case "product-carousel":
                    this.modal.id = "boxtop-modal-pc";
                    break;
                case "coupon-carousel":
                    this.modal.id = "boxtop-modal-cc";
                    break;
                case "coupon-grid":
                    this.modal.id = "boxtop-modal-cg";
                    break;
                case "offer-details":
                    this.modal.id = "boxtop-modal-od";
                    break;
                default:
                    this.modal.id = "boxtop-modal";

            }
            this.modal.isBoxtop = true;
            this.modal.actionButton = "Boxtop modal";
            // Only call once on the page even if it is integrated into more components
            if (this._isRegistered() && (!window["AB"].userInfo.boxTopCalled)) {
                window["AB"].userInfo.boxTopCalled = true;
                if (localStorage.getItem('loyaltyPartners')) {
                    const data = JSON.parse(localStorage.getItem('loyaltyPartners'));
                    if (data['loyaltyPartners']) {
                        data['loyaltyPartners'].forEach(function (loyaltyPartner) {
                            if ((loyaltyPartner) && (loyaltyPartner.name == "GeneralMills") && (loyaltyPartner.planNumber) && (loyaltyPartner.planNumber.length > 1)) {
                                window["AB"].userInfo.boxTopAuth = true;
                            }
                        });
                    }
                } else {
                    this.objBoxTop.getGeneralMillsId().subscribe(data => {
                        localStorage.setItem('loyaltyPartners', JSON.stringify(data));
                        if (data['loyaltyPartners']) {
                            data['loyaltyPartners'].forEach(function (loyaltyPartner) {
                                if ((loyaltyPartner) && (loyaltyPartner.name == "GeneralMills") && (loyaltyPartner.planNumber) && (loyaltyPartner.planNumber.length > 1)) {
                                    window["AB"].userInfo.boxTopAuth = true;
                                }
                            });
                        }
                    });
                }
            }
        } else if (this.modal.type == "service-details") {
            this.modal.id = "service-details";
            this.modal.titleId = "service-details-title";
            this.modal.actionButton = this.elementRef.nativeElement.getAttribute("data-modal-actionButton");
            this.modal.title = this.elementRef.nativeElement.getAttribute("data-modal-title");
            this.modal.leftsubtitle = this.elementRef.nativeElement.getAttribute("data-modal-leftsubtitle");
            this.modal.lefttext = this.elementRef.nativeElement.getAttribute("data-modal-lefttext");
            this.modal.rightsubtitle = this.elementRef.nativeElement.getAttribute("data-modal-rightsubtitle");
            this.modal.righttext = this.elementRef.nativeElement.getAttribute("data-modal-righttext");
            this.modal.rightlinktext = this.elementRef.nativeElement.getAttribute("data-modal-rightlinktext");
            this.modal.rightlink = this.elementRef.nativeElement.getAttribute("data-modal-rightlink");

            if (this.modal.actionButton != null) 
                this.modal.isServiceDetails = true;
             else 
                this.modal.isServiceDetails = false;
        }
    }

    public ngAfterViewInit() {
        // window['AB']['ARIA'].rewardsModalFocus(this.modal.id);
        _window()['AB']['ARIA'].init();
    }

    public clipReward() {
        this.couponClipFn.clipReward(this.modal.reward, this.updateStatistics);
        _window()['location']['href'] = _window()['location']['href'].split('justforu')[0] +'justforu/rewards.html';
        // window['AB']['ARIA'].rewardsModalFocus(this.modal.id);
    }

    private updateStatistics() {
        // update analytics data layer
        window["AB"]["DATALAYER"].pushEvent({ name: "reward_clipped" });
        window["AB"]["DATALAYER"].clipCoupon(this.modal.reward);
    }

    public neverShowBoxtop(){
        localStorage.setItem("showBoxtop",'false');
        this._modalService.cancelBoxtopDisplay();
    }

    public redirectToBoxtopPage(){
        localStorage.setItem('boxtopActionName', 'get_started');
        if(_window()['location']['href'].includes('justforu')){
            _window()['location']['href'] = _window()['location']['href'].split('justforu')[0] + 'boxtops.html';
        }else{
            _window()['location']['href'] = _window()['location']['origin'] + '/boxtops.html';
        }
    }

    public getSelectedRewards(){
        if (this._isRegistered()&&this.modal.isRewardsSelected) {
            this._modalService
            .getSelectedRewardsOffers()
            .subscribe(response => {
                this.rewardsSelected = response;
            });
        }
    }

    private _isRegistered(): boolean {
        return (window['AB']['COMMON'].sessionNotExpired() && window['AB']['COMMON'].authorizeJ4U());
    }
}

==> wcax-shared-angular-1.0.2.tgz: package/modal/modal.component.ts <==
import { Component, Injectable, Input, OnInit, ElementRef, AfterViewInit } from "@angular/core";

// Services
import { ModalService } from "./modal.service";
import { ClipService } from "wcax-core-angular/clip.service";
//import { BoxtopService } from "../../j4u/boxtop/boxtop.service";

// Data model
import { RewardModel } from "../data.model";

// jQuery
declare var $: any;

function _window(): any {
    return window;
}
@Component({
    selector: "modal",
    templateUrl: "./modal.component.html"
})
@Injectable()
export class ModalComponent implements OnInit, AfterViewInit {
    public modal: any = {
        title: "",
        titleBorder: false,
        id: "",
        modalClass: "",
        isRewardsSelected: false,
        isRewardsRedemption: false,
        isBoxtop: false,
        isServiceDetails: false,
        type: '',
        actionButton: '',
        reward: {},
        rewardId: '',
        displayRedemptionButton: false,
        titleId: ''
    };
    public rewardsSelected: RewardModel[] = [];

    public constructor(
        public elementRef: ElementRef,
        private _modalService: ModalService,
        private couponClipFn: ClipService,
     //   private objBoxTop: BoxtopService
    ) {}

    public ngOnInit() {
        if(this.elementRef.nativeElement.getAttribute("data-modal-type")) this.modal.type = this.elementRef.nativeElement.getAttribute("data-modal-type");
        if(this.elementRef.nativeElement.getAttribute("data-modal-parent")) this.modal.parent = this.elementRef.nativeElement.getAttribute("data-modal-parent");
        if(this.elementRef.nativeElement.getAttribute("data-modal-reward-id")) this.modal.rewardId = this.elementRef.nativeElement.getAttribute("data-modal-reward-id");
        if(this.elementRef.nativeElement.getAttribute("data-modal-actionButton")) this.modal.actionButton = this.elementRef.nativeElement.getAttribute("data-modal-actionButton");
        if(this.elementRef.nativeElement.getAttribute("data-modal-displayRedemptionButton")) this.modal.displayRedemptionButton = this.elementRef.nativeElement.getAttribute("data-modal-displayRedemptionButton");

        if (this.modal.type == "rewards-selected") {
            this.modal.title = "My Selected Rewards:";
            this.modal.titleId="rewards-selected-modal-title";
            this.modal.titleBorder = true;
            this.modal.id = "rewards-selected-modal";
            this.modal.describedId = this.modal.titleId;
            this.modal.isRewardsSelected = true;
        } else if (this.modal.type == "boxtop") {
            this.modal.title = "Get started today - enroll in Box Tops for Education";
            this.modal.titleBorder = false;
            this.modal.titleId = 'boxtopModalTitle';
            switch (this.modal.parent) {
                case "product-carousel":
                    this.modal.id = "boxtop-modal-pc";
                    break;
                case "coupon-carousel":
                    this.modal.id = "boxtop-modal-cc";
                    break;
                case "coupon-grid":
                    this.modal.id = "boxtop-modal-cg";
                    break;
                case "offer-details":
                    this.modal.id = "boxtop-modal-od";
                    break;
                default:
                    this.modal.id = "boxtop-modal";

            }
            this.modal.isBoxtop = true;
            this.modal.actionButton = "Boxtop modal";
            // Only call once on the page even if it is integrated into more components
            if (this._isRegistered() && (!window["AB"].userInfo.boxTopCalled)) {
                window["AB"].userInfo.boxTopCalled = true;
//                 if (localStorage.getItem('loyaltyPartners')) {
//                     const data = JSON.parse(localStorage.getItem('loyaltyPartners'));
//                     if (data['loyaltyPartners']) {
//                         data['loyaltyPartners'].forEach(function (loyaltyPartner) {
//                             if ((loyaltyPartner) && (loyaltyPartner.name == "GeneralMills") && (loyaltyPartner.planNumber) && (loyaltyPartner.planNumber.length > 1)) {
//                                 window["AB"].userInfo.boxTopAuth = true;
//                             }
//                         });
//                     }
//                 } else {
//                     this.objBoxTop.getGeneralMillsId().subscribe(data => {
//                         localStorage.setItem('loyaltyPartners', JSON.stringify(data));
//                         if (data['loyaltyPartners']) {
//                             data['loyaltyPartners'].forEach(function (loyaltyPartner) {
//                                 if ((loyaltyPartner) && (loyaltyPartner.name == "GeneralMills") && (loyaltyPartner.planNumber) && (loyaltyPartner.planNumber.length > 1)) {
//                                     window["AB"].userInfo.boxTopAuth = true;
//                                 }
//                             });
//                         }
//                     });
//               }
            }
        } else if (this.modal.type == "service-details") {
            this.modal.id = "service-details";
            this.modal.titleId = "service-details-title";
            this.modal.actionButton = this.elementRef.nativeElement.getAttribute("data-modal-actionButton");
            this.modal.title = this.elementRef.nativeElement.getAttribute("data-modal-title");
            this.modal.leftsubtitle = this.elementRef.nativeElement.getAttribute("data-modal-leftsubtitle");
            this.modal.lefttext = this.elementRef.nativeElement.getAttribute("data-modal-lefttext");
            this.modal.rightsubtitle = this.elementRef.nativeElement.getAttribute("data-modal-rightsubtitle");
            this.modal.righttext = this.elementRef.nativeElement.getAttribute("data-modal-righttext");
            this.modal.rightlinktext = this.elementRef.nativeElement.getAttribute("data-modal-rightlinktext");
            this.modal.rightlink = this.elementRef.nativeElement.getAttribute("data-modal-rightlink");

            if (this.modal.actionButton != null)
                this.modal.isServiceDetails = true;
             else
                this.modal.isServiceDetails = false;
        }
    }

    public ngAfterViewInit() {
        // window['AB']['ARIA'].rewardsModalFocus(this.modal.id);
        _window()['AB']['ARIA'].init();
    }

    public clipReward() {
        this.couponClipFn.clipReward(this.modal.reward, this.updateStatistics);
        _window()['location']['href'] = _window()['location']['href'].split('justforu')[0] +'justforu/rewards.html';
        // window['AB']['ARIA'].rewardsModalFocus(this.modal.id);
    }

    private updateStatistics() {
        // update analytics data layer
        window["AB"]["DATALAYER"].pushEvent({ name: "reward_clipped" });
        window["AB"]["DATALAYER"].clipCoupon(this.modal.reward);
    }

    public neverShowBoxtop(){
        localStorage.setItem("showBoxtop",'false');
        this._modalService.cancelBoxtopDisplay();
    }

    public redirectToBoxtopPage(){
        localStorage.setItem('boxtopActionName', 'get_started');
        if(_window()['location']['href'].includes('justforu')){
            _window()['location']['href'] = _window()['location']['href'].split('justforu')[0] + 'boxtops.html';
        }else{
            _window()['location']['href'] = _window()['location']['origin'] + '/boxtops.html';
        }
    }

    public getSelectedRewards(){
        if (this._isRegistered()&&this.modal.isRewardsSelected) {
            this._modalService
            .getSelectedRewardsOffers()
            .subscribe(response => {
                this.rewardsSelected = response;
            });
        }
    }

    private _isRegistered(): boolean {
        return (window['AB']['COMMON'].sessionNotExpired() && window['AB']['COMMON'].authorizeJ4U());
    }
}
